@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Optional, Union
 
-from typing_extensions import Literal, NotRequired, TypedDict
+from typing_extensions import Literal, NotRequired, TypedDict, final
 
 if TYPE_CHECKING:
     from ..shared import Snowflake
@@ -33,18 +33,21 @@ class GuildScheduledEventBase(TypedDict):
     user_count: NotRequired[int]
 
 
+@final
 class StageGuildScheduledEventData(GuildScheduledEventBase):
     channel_id: Snowflake
     entity_metadata: None
     scheduled_end_time: NotRequired[str]
 
 
+@final
 class VoiceGuildScheduledEventData(GuildScheduledEventBase):
     channel_id: Snowflake
     entity_metadata: None
     scheduled_end_time: NotRequired[str]
 
 
+@final
 class ExternalGuildScheduledEventData(GuildScheduledEventBase):
     channel_id: None
     entity_metadata: GuildScheduledEventEntityMetadata
@@ -61,6 +64,7 @@ GuildScheduledEventData = Union[
 # https://discord.com/developers/docs/resources/guild-scheduled-event#guild-scheduled-event-object-guild-scheduled-event-entity-metadata
 
 
+@final
 class GuildScheduledEventEntityMetadata(TypedDict):
     location: NotRequired[str]
 
@@ -68,7 +72,8 @@ class GuildScheduledEventEntityMetadata(TypedDict):
 # https://discord.com/developers/docs/resources/guild-scheduled-event#guild-scheduled-event-user-object-guild-scheduled-event-user-structure
 
 
+@final
 class GuildScheduledEventUserData(TypedDict):
     guild_scheduled_event_id: Snowflake
     user: UserData
-    memer: NotRequired[GuildMemberData]
+    member: NotRequired[GuildMemberData]
