@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
-from typing_extensions import Literal, TypedDict
+from typing_extensions import Literal, TypedDict, final
 
 if TYPE_CHECKING:
     from ..shared import Snowflake
@@ -13,6 +13,7 @@ __all__ = ('StageInstanceData',)
 # https://discord.com/developers/docs/resources/stage-instance#stage-instance-object-stage-instance-structure
 
 
+@final
 class StageInstanceData(TypedDict):
     id: Snowflake
     guild_id: Snowflake
