@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Optional
 
-from typing_extensions import NotRequired, TypedDict
+from typing_extensions import NotRequired, TypedDict, final
 
 if TYPE_CHECKING:
     from ..shared import Snowflake
@@ -14,6 +14,7 @@ __all__ = ('VoiceStateData', 'VoiceRegionData')
 # https://discord.com/developers/docs/resources/voice#voice-state-object-voice-state-structure
 
 
+@final
 class VoiceStateData(TypedDict):
     guild_id: NotRequired[Snowflake]
     channel_id: Optional[Snowflake]
@@ -33,6 +34,7 @@ class VoiceStateData(TypedDict):
 # https://discord.com/developers/docs/resources/voice#voice-region-object-voice-region-structure
 
 
+@final
 class VoiceRegionData(TypedDict):
     id: str
     name: str
